# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from sailpoint.v3.models.vendor_connector_mapping_deleted_at import VendorConnectorMappingDeletedAt
from sailpoint.v3.models.vendor_connector_mapping_deleted_by import VendorConnectorMappingDeletedBy
from sailpoint.v3.models.vendor_connector_mapping_updated_at import VendorConnectorMappingUpdatedAt
from sailpoint.v3.models.vendor_connector_mapping_updated_by import VendorConnectorMappingUpdatedBy
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class VendorConnectorMapping(BaseModel):
    """
    VendorConnectorMapping
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The unique identifier for the vendor-connector mapping.")
    vendor: Optional[StrictStr] = Field(default=None, description="The name of the vendor.")
    connector: Optional[StrictStr] = Field(default=None, description="The name of the connector.")
    created_at: Optional[datetime] = Field(default=None, description="The creation timestamp of the mapping.", alias="createdAt")
    created_by: Optional[StrictStr] = Field(default=None, description="The identifier of the user who created the mapping.", alias="createdBy")
    updated_at: Optional[VendorConnectorMappingUpdatedAt] = Field(default=None, alias="updatedAt")
    updated_by: Optional[VendorConnectorMappingUpdatedBy] = Field(default=None, alias="updatedBy")
    deleted_at: Optional[VendorConnectorMappingDeletedAt] = Field(default=None, alias="deletedAt")
    deleted_by: Optional[VendorConnectorMappingDeletedBy] = Field(default=None, alias="deletedBy")
    __properties: ClassVar[List[str]] = ["id", "vendor", "connector", "createdAt", "createdBy", "updatedAt", "updatedBy", "deletedAt", "deletedBy"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of VendorConnectorMapping from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of updated_at
        if self.updated_at:
            _dict['updatedAt'] = self.updated_at.to_dict()
        # override the default output from pydantic by calling `to_dict()` of updated_by
        if self.updated_by:
            _dict['updatedBy'] = self.updated_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of deleted_at
        if self.deleted_at:
            _dict['deletedAt'] = self.deleted_at.to_dict()
        # override the default output from pydantic by calling `to_dict()` of deleted_by
        if self.deleted_by:
            _dict['deletedBy'] = self.deleted_by.to_dict()
        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict['updatedAt'] = None

        # set to None if updated_by (nullable) is None
        # and model_fields_set contains the field
        if self.updated_by is None and "updated_by" in self.model_fields_set:
            _dict['updatedBy'] = None

        # set to None if deleted_at (nullable) is None
        # and model_fields_set contains the field
        if self.deleted_at is None and "deleted_at" in self.model_fields_set:
            _dict['deletedAt'] = None

        # set to None if deleted_by (nullable) is None
        # and model_fields_set contains the field
        if self.deleted_by is None and "deleted_by" in self.model_fields_set:
            _dict['deletedBy'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of VendorConnectorMapping from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "vendor": obj.get("vendor"),
            "connector": obj.get("connector"),
            "createdAt": obj.get("createdAt"),
            "createdBy": obj.get("createdBy"),
            "updatedAt": VendorConnectorMappingUpdatedAt.from_dict(obj.get("updatedAt")) if obj.get("updatedAt") is not None else None,
            "updatedBy": VendorConnectorMappingUpdatedBy.from_dict(obj.get("updatedBy")) if obj.get("updatedBy") is not None else None,
            "deletedAt": VendorConnectorMappingDeletedAt.from_dict(obj.get("deletedAt")) if obj.get("deletedAt") is not None else None,
            "deletedBy": VendorConnectorMappingDeletedBy.from_dict(obj.get("deletedBy")) if obj.get("deletedBy") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, field_validator
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class NativeChangeDetectionConfig(BaseModel):
    """
    Source configuration information for Native Change Detection that is read and used by account aggregation process.
    """ # noqa: E501
    enabled: Optional[StrictBool] = Field(default=False, description="A flag indicating if Native Change Detection is enabled for a source.")
    operations: Optional[List[StrictStr]] = Field(default=None, description="Operation types for which Native Change Detection is enabled for a source.")
    all_entitlements: Optional[StrictBool] = Field(default=False, description="A flag indicating that all entitlements participate in Native Change Detection.", alias="allEntitlements")
    all_non_entitlement_attributes: Optional[StrictBool] = Field(default=False, description="A flag indicating that all non-entitlement account attributes participate in Native Change Detection.", alias="allNonEntitlementAttributes")
    selected_entitlements: Optional[List[StrictStr]] = Field(default=None, description="If allEntitlements flag is off this field lists entitlements that participate in Native Change Detection.", alias="selectedEntitlements")
    selected_non_entitlement_attributes: Optional[List[StrictStr]] = Field(default=None, description="If allNonEntitlementAttributes flag is off this field lists non-entitlement account attributes that participate in Native Change Detection.", alias="selectedNonEntitlementAttributes")
    __properties: ClassVar[List[str]] = ["enabled", "operations", "allEntitlements", "allNonEntitlementAttributes", "selectedEntitlements", "selectedNonEntitlementAttributes"]

    @field_validator('operations')
    def operations_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in ('ACCOUNT_UPDATED', 'ACCOUNT_CREATED', 'ACCOUNT_DELETED'):
                raise ValueError("each list item must be one of ('ACCOUNT_UPDATED', 'ACCOUNT_CREATED', 'ACCOUNT_DELETED')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NativeChangeDetectionConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of NativeChangeDetectionConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else False,
            "operations": obj.get("operations"),
            "allEntitlements": obj.get("allEntitlements") if obj.get("allEntitlements") is not None else False,
            "allNonEntitlementAttributes": obj.get("allNonEntitlementAttributes") if obj.get("allNonEntitlementAttributes") is not None else False,
            "selectedEntitlements": obj.get("selectedEntitlements"),
            "selectedNonEntitlementAttributes": obj.get("selectedNonEntitlementAttributes")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.work_reassignment_api import WorkReassignmentApi


class TestWorkReassignmentApi(unittest.TestCase):
    """WorkReassignmentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkReassignmentApi()

    def tearDown(self) -> None:
        pass

    def test_create_reassignment_configuration(self) -> None:
        """Test case for create_reassignment_configuration

        Create a Reassignment Configuration
        """
        pass

    def test_delete_reassignment_configuration(self) -> None:
        """Test case for delete_reassignment_configuration

        Delete Reassignment Configuration
        """
        pass

    def test_get_evaluate_reassignment_configuration(self) -> None:
        """Test case for get_evaluate_reassignment_configuration

        Evaluate Reassignment Configuration
        """
        pass

    def test_get_reassignment_config_types(self) -> None:
        """Test case for get_reassignment_config_types

        List Reassignment Config Types
        """
        pass

    def test_get_reassignment_configuration(self) -> None:
        """Test case for get_reassignment_configuration

        Get Reassignment Configuration
        """
        pass

    def test_get_tenant_config_configuration(self) -> None:
        """Test case for get_tenant_config_configuration

        Get Tenant-wide Reassignment Configuration settings
        """
        pass

    def test_list_reassignment_configurations(self) -> None:
        """Test case for list_reassignment_configurations

        List Reassignment Configurations
        """
        pass

    def test_put_reassignment_config(self) -> None:
        """Test case for put_reassignment_config

        Update Reassignment Configuration
        """
        pass

    def test_put_tenant_configuration(self) -> None:
        """Test case for put_tenant_configuration

        Update Tenant-wide Reassignment Configuration settings
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.managed_clusters_api import ManagedClustersApi


class TestManagedClustersApi(unittest.TestCase):
    """ManagedClustersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ManagedClustersApi()

    def tearDown(self) -> None:
        pass

    def test_get_client_log_configuration(self) -> None:
        """Test case for get_client_log_configuration

        Get managed cluster's log configuration
        """
        pass

    def test_get_managed_cluster(self) -> None:
        """Test case for get_managed_cluster

        Get a specified ManagedCluster.
        """
        pass

    def test_get_managed_clusters(self) -> None:
        """Test case for get_managed_clusters

        Retrieve all Managed Clusters.
        """
        pass

    def test_put_client_log_configuration(self) -> None:
        """Test case for put_client_log_configuration

        Update managed cluster's log configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr
from pydantic import Field
from sailpoint.beta.models.campaign_reference import CampaignReference
from sailpoint.beta.models.certification_phase import CertificationPhase
from sailpoint.beta.models.reassignment import Reassignment
from sailpoint.beta.models.reviewer import Reviewer
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class CertificationDto(BaseModel):
    """
    CertificationDto
    """ # noqa: E501
    campaign_ref: CampaignReference = Field(alias="campaignRef")
    phase: CertificationPhase
    due: datetime = Field(description="The due date of the certification.")
    signed: datetime = Field(description="The date the reviewer signed off on the certification.")
    reviewer: Reviewer
    reassignment: Optional[Reassignment] = None
    has_errors: StrictBool = Field(description="Indicates it the certification has any errors.", alias="hasErrors")
    error_message: Optional[StrictStr] = Field(default=None, description="A message indicating what the error is.", alias="errorMessage")
    completed: StrictBool = Field(description="Indicates if all certification decisions have been made.")
    decisions_made: StrictInt = Field(description="The number of approve/revoke/acknowledge decisions that have been made by the reviewer.", alias="decisionsMade")
    decisions_total: StrictInt = Field(description="The total number of approve/revoke/acknowledge decisions for the certification.", alias="decisionsTotal")
    entities_completed: StrictInt = Field(description="The number of entities (identities, access profiles, roles, etc.) for which all decisions have been made and are complete.", alias="entitiesCompleted")
    entities_total: StrictInt = Field(description="The total number of entities (identities, access profiles, roles, etc.) in the certification, both complete and incomplete.", alias="entitiesTotal")
    __properties: ClassVar[List[str]] = ["campaignRef", "phase", "due", "signed", "reviewer", "reassignment", "hasErrors", "errorMessage", "completed", "decisionsMade", "decisionsTotal", "entitiesCompleted", "entitiesTotal"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CertificationDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of campaign_ref
        if self.campaign_ref:
            _dict['campaignRef'] = self.campaign_ref.to_dict()
        # override the default output from pydantic by calling `to_dict()` of reviewer
        if self.reviewer:
            _dict['reviewer'] = self.reviewer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of reassignment
        if self.reassignment:
            _dict['reassignment'] = self.reassignment.to_dict()
        # set to None if error_message (nullable) is None
        # and model_fields_set contains the field
        if self.error_message is None and "error_message" in self.model_fields_set:
            _dict['errorMessage'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of CertificationDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "campaignRef": CampaignReference.from_dict(obj.get("campaignRef")) if obj.get("campaignRef") is not None else None,
            "phase": obj.get("phase"),
            "due": obj.get("due"),
            "signed": obj.get("signed"),
            "reviewer": Reviewer.from_dict(obj.get("reviewer")) if obj.get("reviewer") is not None else None,
            "reassignment": Reassignment.from_dict(obj.get("reassignment")) if obj.get("reassignment") is not None else None,
            "hasErrors": obj.get("hasErrors"),
            "errorMessage": obj.get("errorMessage"),
            "completed": obj.get("completed"),
            "decisionsMade": obj.get("decisionsMade"),
            "decisionsTotal": obj.get("decisionsTotal"),
            "entitiesCompleted": obj.get("entitiesCompleted"),
            "entitiesTotal": obj.get("entitiesTotal")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictInt, StrictStr, field_validator
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class ManagedClient(BaseModel):
    """
    Managed Client
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="ManagedClient ID")
    alert_key: Optional[StrictStr] = Field(default=None, description="ManagedClient alert key", alias="alertKey")
    cc_id: Optional[StrictInt] = Field(default=None, description="Previous CC ID to be used in data migration. (This field will be deleted after CC migration!)", alias="ccId")
    client_id: StrictStr = Field(description="The client ID used in API management", alias="clientId")
    cluster_id: StrictStr = Field(description="Cluster ID that the ManagedClient is linked to", alias="clusterId")
    description: StrictStr = Field(description="ManagedClient description")
    ip_address: Optional[StrictStr] = Field(default=None, description="The public IP address of the ManagedClient", alias="ipAddress")
    last_seen: Optional[datetime] = Field(default=None, description="When the ManagedClient was last seen by the server", alias="lastSeen")
    name: Optional[StrictStr] = Field(default='VA-$clientId', description="ManagedClient name")
    since_last_seen: Optional[StrictStr] = Field(default=None, description="Milliseconds since the ManagedClient has polled the server", alias="sinceLastSeen")
    status: Optional[StrictStr] = Field(default=None, description="Status of the ManagedClient")
    type: StrictStr = Field(description="Type of the ManagedClient (VA, CCG)")
    cluster_type: Optional[StrictStr] = Field(default=None, description="Cluster Type of the ManagedClient", alias="clusterType")
    va_download_url: Optional[StrictStr] = Field(default=None, description="ManagedClient VA download URL", alias="vaDownloadUrl")
    va_version: Optional[StrictStr] = Field(default=None, description="Version that the ManagedClient's VA is running", alias="vaVersion")
    secret: Optional[StrictStr] = Field(default=None, description="Client's apiKey")
    created_at: Optional[datetime] = Field(default=None, description="The date/time this ManagedClient was created", alias="createdAt")
    updated_at: Optional[datetime] = Field(default=None, description="The date/time this ManagedClient was last updated", alias="updatedAt")
    provision_status: Optional[StrictStr] = Field(default=None, description="The provisioning status of the ManagedClient", alias="provisionStatus")
    __properties: ClassVar[List[str]] = ["id", "alertKey", "ccId", "clientId", "clusterId", "description", "ipAddress", "lastSeen", "name", "sinceLastSeen", "status", "type", "clusterType", "vaDownloadUrl", "vaVersion", "secret", "createdAt", "updatedAt", "provisionStatus"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('NORMAL', 'UNDEFINED', 'NOT_CONFIGURED', 'CONFIGURING', 'WARNING', 'ERROR', 'FAILED', 'null'):
            raise ValueError("must be one of enum values ('NORMAL', 'UNDEFINED', 'NOT_CONFIGURED', 'CONFIGURING', 'WARNING', 'ERROR', 'FAILED', 'null')")
        return value

    @field_validator('cluster_type')
    def cluster_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('null', 'idn', 'iai', 'spConnectCluster', 'sqsCluster', 'das-rc', 'das-pc', 'das-dc'):
            raise ValueError("must be one of enum values ('null', 'idn', 'iai', 'spConnectCluster', 'sqsCluster', 'das-rc', 'das-pc', 'das-dc')")
        return value

    @field_validator('provision_status')
    def provision_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('null', 'PROVISIONED', 'DRAFT'):
            raise ValueError("must be one of enum values ('null', 'PROVISIONED', 'DRAFT')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ManagedClient from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "id",
                "alert_key",
                "ip_address",
                "last_seen",
                "since_last_seen",
                "status",
                "cluster_type",
                "va_download_url",
                "va_version",
                "provision_status",
            },
            exclude_none=True,
        )
        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if alert_key (nullable) is None
        # and model_fields_set contains the field
        if self.alert_key is None and "alert_key" in self.model_fields_set:
            _dict['alertKey'] = None

        # set to None if cc_id (nullable) is None
        # and model_fields_set contains the field
        if self.cc_id is None and "cc_id" in self.model_fields_set:
            _dict['ccId'] = None

        # set to None if ip_address (nullable) is None
        # and model_fields_set contains the field
        if self.ip_address is None and "ip_address" in self.model_fields_set:
            _dict['ipAddress'] = None

        # set to None if last_seen (nullable) is None
        # and model_fields_set contains the field
        if self.last_seen is None and "last_seen" in self.model_fields_set:
            _dict['lastSeen'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if since_last_seen (nullable) is None
        # and model_fields_set contains the field
        if self.since_last_seen is None and "since_last_seen" in self.model_fields_set:
            _dict['sinceLastSeen'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if cluster_type (nullable) is None
        # and model_fields_set contains the field
        if self.cluster_type is None and "cluster_type" in self.model_fields_set:
            _dict['clusterType'] = None

        # set to None if va_download_url (nullable) is None
        # and model_fields_set contains the field
        if self.va_download_url is None and "va_download_url" in self.model_fields_set:
            _dict['vaDownloadUrl'] = None

        # set to None if va_version (nullable) is None
        # and model_fields_set contains the field
        if self.va_version is None and "va_version" in self.model_fields_set:
            _dict['vaVersion'] = None

        # set to None if secret (nullable) is None
        # and model_fields_set contains the field
        if self.secret is None and "secret" in self.model_fields_set:
            _dict['secret'] = None

        # set to None if created_at (nullable) is None
        # and model_fields_set contains the field
        if self.created_at is None and "created_at" in self.model_fields_set:
            _dict['createdAt'] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict['updatedAt'] = None

        # set to None if provision_status (nullable) is None
        # and model_fields_set contains the field
        if self.provision_status is None and "provision_status" in self.model_fields_set:
            _dict['provisionStatus'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of ManagedClient from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "alertKey": obj.get("alertKey"),
            "ccId": obj.get("ccId"),
            "clientId": obj.get("clientId"),
            "clusterId": obj.get("clusterId"),
            "description": obj.get("description") if obj.get("description") is not None else '',
            "ipAddress": obj.get("ipAddress"),
            "lastSeen": obj.get("lastSeen"),
            "name": obj.get("name") if obj.get("name") is not None else 'VA-$clientId',
            "sinceLastSeen": obj.get("sinceLastSeen"),
            "status": obj.get("status"),
            "type": obj.get("type"),
            "clusterType": obj.get("clusterType"),
            "vaDownloadUrl": obj.get("vaDownloadUrl"),
            "vaVersion": obj.get("vaVersion"),
            "secret": obj.get("secret"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "provisionStatus": obj.get("provisionStatus")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.sources_api import SourcesApi


class TestSourcesApi(unittest.TestCase):
    """SourcesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SourcesApi()

    def tearDown(self) -> None:
        pass

    def test_create_provisioning_policy(self) -> None:
        """Test case for create_provisioning_policy

        Create Provisioning Policy
        """
        pass

    def test_create_source(self) -> None:
        """Test case for create_source

        Creates a source in IdentityNow.
        """
        pass

    def test_create_source_schema(self) -> None:
        """Test case for create_source_schema

        Create Schema on Source
        """
        pass

    def test_delete(self) -> None:
        """Test case for delete

        Delete Source by ID
        """
        pass

    def test_delete_accounts_async(self) -> None:
        """Test case for delete_accounts_async

        Remove All Accounts in a Source
        """
        pass

    def test_delete_native_change_detection_config(self) -> None:
        """Test case for delete_native_change_detection_config

        Delete Native Change Detection Configuration
        """
        pass

    def test_delete_provisioning_policy(self) -> None:
        """Test case for delete_provisioning_policy

        Delete Provisioning Policy by UsageType
        """
        pass

    def test_delete_source_schema(self) -> None:
        """Test case for delete_source_schema

        Delete Source Schema by ID
        """
        pass

    def test_get_correlation_config(self) -> None:
        """Test case for get_correlation_config

        Get Source Correlation Configuration
        """
        pass

    def test_get_native_change_detection_config(self) -> None:
        """Test case for get_native_change_detection_config

        Native Change Detection Configuration
        """
        pass

    def test_get_provisioning_policy(self) -> None:
        """Test case for get_provisioning_policy

        Get Provisioning Policy by UsageType
        """
        pass

    def test_get_source(self) -> None:
        """Test case for get_source

        Get Source by ID
        """
        pass

    def test_get_source_accounts_schema(self) -> None:
        """Test case for get_source_accounts_schema

        Downloads source accounts schema template
        """
        pass

    def test_get_source_attr_sync_config(self) -> None:
        """Test case for get_source_attr_sync_config

        Attribute Sync Config
        """
        pass

    def test_get_source_config(self) -> None:
        """Test case for get_source_config

        Gets source config with language translations
        """
        pass

    def test_get_source_entitlement_request_config(self) -> None:
        """Test case for get_source_entitlement_request_config

        Get Source Entitlement Request Configuration
        """
        pass

    def test_get_source_entitlements_schema(self) -> None:
        """Test case for get_source_entitlements_schema

        Downloads source entitlements schema template
        """
        pass

    def test_get_source_schema(self) -> None:
        """Test case for get_source_schema

        Get Source Schema by ID
        """
        pass

    def test_get_source_schemas(self) -> None:
        """Test case for get_source_schemas

        List Schemas on Source
        """
        pass

    def test_import_accounts(self) -> None:
        """Test case for import_accounts

        Account Aggregation
        """
        pass

    def test_import_entitlements(self) -> None:
        """Test case for import_entitlements

        Entitlement Aggregation
        """
        pass

    def test_import_source_accounts_schema(self) -> None:
        """Test case for import_source_accounts_schema

        Uploads source accounts schema template
        """
        pass

    def test_import_source_connector_file(self) -> None:
        """Test case for import_source_connector_file

        Upload connector file to source
        """
        pass

    def test_import_source_entitlements_schema(self) -> None:
        """Test case for import_source_entitlements_schema

        Uploads source entitlements schema template
        """
        pass

    def test_import_uncorrelated_accounts(self) -> None:
        """Test case for import_uncorrelated_accounts

        Process Uncorrelated Accounts
        """
        pass

    def test_list_provisioning_policies(self) -> None:
        """Test case for list_provisioning_policies

        Lists ProvisioningPolicies
        """
        pass

    def test_list_sources(self) -> None:
        """Test case for list_sources

        Lists all sources in IdentityNow.
        """
        pass

    def test_peek_resource_objects(self) -> None:
        """Test case for peek_resource_objects

        Peek source connector's resource objects
        """
        pass

    def test_ping_cluster(self) -> None:
        """Test case for ping_cluster

        Ping cluster for source connector
        """
        pass

    def test_put_correlation_config(self) -> None:
        """Test case for put_correlation_config

        Update Source Correlation Configuration
        """
        pass

    def test_put_native_change_detection_config(self) -> None:
        """Test case for put_native_change_detection_config

        Update Native Change Detection Configuration
        """
        pass

    def test_put_provisioning_policy(self) -> None:
        """Test case for put_provisioning_policy

        Update Provisioning Policy by UsageType
        """
        pass

    def test_put_source(self) -> None:
        """Test case for put_source

        Update Source (Full)
        """
        pass

    def test_put_source_attr_sync_config(self) -> None:
        """Test case for put_source_attr_sync_config

        Update Attribute Sync Config
        """
        pass

    def test_put_source_schema(self) -> None:
        """Test case for put_source_schema

        Update Source Schema (Full)
        """
        pass

    def test_sync_attributes_for_source(self) -> None:
        """Test case for sync_attributes_for_source

        Synchronize single source attributes.
        """
        pass

    def test_test_source_configuration(self) -> None:
        """Test case for test_source_configuration

        Test configuration for source connector
        """
        pass

    def test_test_source_connection(self) -> None:
        """Test case for test_source_connection

        Check connection for source connector.
        """
        pass

    def test_update_provisioning_policies_in_bulk(self) -> None:
        """Test case for update_provisioning_policies_in_bulk

        Bulk Update Provisioning Policies
        """
        pass

    def test_update_provisioning_policy(self) -> None:
        """Test case for update_provisioning_policy

        Partial update of Provisioning Policy
        """
        pass

    def test_update_source(self) -> None:
        """Test case for update_source

        Update Source (Partial)
        """
        pass

    def test_update_source_entitlement_request_config(self) -> None:
        """Test case for update_source_entitlement_request_config

        Update Source Entitlement Request Configuration
        """
        pass

    def test_update_source_schema(self) -> None:
        """Test case for update_source_schema

        Update Source Schema (Partial)
        """
        pass


if __name__ == '__main__':
    unittest.main()
